==> jodd-all-4.0.0-sources.jar: jodd/madvoc/injector/MadvocParamsInjector.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.madvoc.injector;

import jodd.madvoc.MadvocConfig;
import jodd.petite.ParamManager;
import jodd.petite.PetiteContainer;

/**
 * Specific non-scoped injector that injects Madvoc parameters (from madvoc.props to targets).
 * Invoked on creation of all singleton instances, like interceptors etc.
 * Used to configure various Madvoc classes that are created in lazy manner.
 */
public class MadvocParamsInjector implements ContextInjector<PetiteContainer> {

	protected final MadvocConfig madvocConfig;

	public MadvocParamsInjector(final MadvocConfig madvocConfig) {
		this.madvocConfig = madvocConfig;
	}

	/**
	 * Injects all matching parameters to target instance.
	 * Matching parameters are named as given base name.
	 */
	@Override
	public void injectContext(final Targets targets, final PetiteContainer madpc) {
		targets.forEachTarget(target -> {
			Class targetType = target.resolveType();
			String baseName = targetType.getName();

			ParamManager madvocPetiteParamManager = madpc.paramManager();

			String[] params = madvocPetiteParamManager.resolve(baseName, true);

			for (String param : params) {
				Object value = madvocPetiteParamManager.get(param);

				String propertyName = param.substring(baseName.length() + 1);

				target.writeValue(propertyName, value, false);
			}
		});
	}

}

==> jodd-all-4.1.5-sources.jar: jodd/madvoc/injector/MadvocParamsInjector.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.madvoc.injector;

import jodd.madvoc.MadvocConfig;
import jodd.petite.ParamManager;
import jodd.petite.PetiteContainer;

/**
 * Specific non-scoped injector that injects Madvoc parameters (from madvoc.props to targets).
 * Invoked on creation of all singleton instances, like interceptors etc.
 * Used to configure various Madvoc classes that are created in lazy manner.
 */
public class MadvocParamsInjector implements ContextInjector<PetiteContainer> {

	protected final MadvocConfig madvocConfig;

	public MadvocParamsInjector(final MadvocConfig madvocConfig) {
		this.madvocConfig = madvocConfig;
	}

	/**
	 * Injects all matching parameters to target instance.
	 * Matching parameters are named as given base name.
	 */
	@Override
	public void injectContext(final Targets targets, final PetiteContainer madpc) {
		targets.forEachTarget(target -> {
			Class targetType = target.resolveType();
			String baseName = targetType.getName();

			ParamManager madvocPetiteParamManager = madpc.paramManager();

			String[] params = madvocPetiteParamManager.filterParametersForBeanName(baseName, true);

			for (String param : params) {
				Object value = madvocPetiteParamManager.get(param);

				String propertyName = param.substring(baseName.length() + 1);

				target.writeValue(propertyName, value, false);
			}
		});
	}

}
